if length(dbstack)==1
  clear 
  close all
  NumEigs=12; % Number of eigenvalues (and eigenvectors) to find
  N=150;
  sigma='sm';
  nfig=100;
  demo=false;
end

geofile='disk5holes';
fprintf('------------------------------------------------------\n'); 
fprintf('Running sample: %s\n',mfilename());
fprintf('------------------------------------------------------\n'); 
fprintf('      2D Laplacian eBVP using gmsh with %s.geo (N=%d) :\n\n',geofile,N);
fprintf('             -Laplacian(u) = lambda*u \n');
fprintf('        with \n');
fprintf('          * Dirichlet boundary conditions on [1,10]\n');
fprintf('          * Neumann boundary conditions on   [20,21]\n');
fprintf('          * Robin boundary conditions on     [22,23]\n');
fprintf('             dn(u) + 10*u = 0\n');
fprintf('------------------------------------------------------\n');

[curpath,~,~]=fileparts(mfilename('fullpath'));
tstart=tic();
meshfile=gmsh.buildmesh2d(geofile,N,'geodir',[curpath,filesep,'geodir'],'meshdir',[curpath,filesep,'meshdir']);
dim=2;d=2;
Th=siMesh(meshfile,'dim',dim,'format','gmsh');
T(1)=toc(tstart);
fprintf('*** Generate and read mesh file in : %.3f(s)\n',T(1));
info(Th)

tstart=tic();
Lop=Loperator(dim,d,{1,0;0,1},[],[],[]);
pde=PDEelt(Lop);
bvp=BVP(Th,pde);
bvp.setDirichlet( 1, 0.);
bvp.setDirichlet( 10, 0.);
bvp.setRobin( 20, 0.,[]);bvp.setRobin( 21, 0.,[]);
bvp.setRobin( 22, 0.,10.);bvp.setRobin( 23, 0.,10.);
T(2)=toc(tstart);
fprintf('*** Set eBVP in : %.3f(s)\n',T(2));

% Computation of numerical eigenvectors and eigenvalues
tstart=tic();
[eVec,eVal,flag]=fc_vfemp1.addon.eigs.solve(bvp,NumEigs,sigma);
T(3)=toc(tstart);
if flag~=0, warning('function eigs trouble: not all eigenvalues converged!');end
fprintf('*** Solve eBVP with %d eigenvalues in : %.3f(s)\n',NumEigs,T(3));

tstart=tic();
[eVec,eVal]=fc_vfemp1.addon.eigs.splitsort(bvp,eVec,eVal);
fc_vfemp1.addon.eigs.plot(Th,eVec,eVal,'demo',demo)
drawnow
T(4)=toc(tstart);
fprintf('*** Graphical representations in : %.3f(s)\n',T(4));

if ~demo
  figure(1)
  Th.plotmesh('color',0.9*[1,1,1])
  hold on
  axis image
  Th.plotmesh('d',1,'legend',true,'linewidth',2)
end